==> dtfu_install-1.0.2.tar.gz: doc/readme.md <==
# 自动数据FTP上传 :id=top

> _Doc Ver:_ 1.2  
_App Ver:_ 1.0.2  
_Date:_ 12/19/2022

dtfu: Data ftp upload;  
定期检测目标数据目录；  
并将未上传的历史数据或则最新数据上传到指定ftp服务器中。

## 1. 安装 :id=install

  * 下载安装包:  
    http://112.74.80.60/tools/dtfu/linux/amd64/latest/dtfu_install.tar.gz
  * 拷贝: 将下载的安装包拷贝至系统的用户根目录;
  * 解压
    通过系统命令行进入下载包存放目录，运行指令解压;
    ```
        tar -xzvf dtfu_install.tar.gz
    ```
  * 安装
    ```
        cd dtfu_install
        bash install.sh
    ```
  * 配置启动参数
    需要配置启动参数才能运行，系统无默认配置文件。
    可以配置为多个FTP服务器接收模式。
    ```
        cd ~/dtfu
        ./configure
    ```
  * 增加自启动
    在自启动脚本中，增加以下命令实现自启动，重启系统后生效。   
    如果系统中安装有解调仪单机程序，需要将本程序自启动项目置于解调仪程序前。
    ```
        sudo -u debian dtfu_run start &
        
        debian: 为系统默认的sudo主账户
    ```

## 2. 配置参数 :id=configure 

   ```
        Source data dir [default: /var/sa/data/rt/]
        数据源目录。
        
        Log file [default: dtfu.log] 
        上传文件记录 

        Source data files ignored [default: *.dat]
        是否忽略特定文件。

        Source files deleted after uploaded, 'yes' or 'no' [default: no]
        是否删除数据源文件，如果有多个FTP服务器上传，此项失效。

        Check interval [default: 6]
        新文件检查时间间隔（单位：秒）。

        FTP server number [default: 2]
        需要配置的FTP接收服务器的数量。

        Detect ftp config file: /var/sa/conf/data_save.json, 'y' for load it.
        如果系统安装了"sa"程序，将自动侦测配置文件，并自动禁用保存配置中的sa自动FTP上传功能。

        User & Passwd: FTP的用户名密码。
        URL: FTP的接收网络地址。

        Test FTP link now? 'y' for yes. 
        确认是否FTP配置正确，将自动上传测试文件以确认。
   ```

## 3. 进度查看 :id=monitor 

  通过广播接口，可以实时查看转存程序的运行状态，包括异常，结束，正在处理的文件情况。
  * Linux系统
  在与备份服务器同网络的任意Linux电脑上，运行以下程序;
  ```
    nc -l -u -k -p 7070

    7070: 为dtfu.cfg（交互配置后自动生成）文件中"process_udp_port"定义的接口。
    -l: 监听  
    -u: upd  
    -k: 保持链接，不会因为一帧数据接收后就结束。  
    -p: 监听端口  
  ```

## 更改历史 :id=changelog

|版本|日期|说明|
|:--:|----|----------|
|1.2|12/19/2022|1. 修改启动方式，增加多服务端上传;<br/>2. 增加选择文件过滤功能;<br/>3. 更改配置文件修改方式为交互式。|
|1.1|12/10/2022|1. 修正正写入文件的探测，并禁止上传。|
|1.0|12/10/2022|1. 适用新文件格式创建帮助。|

------

[Top](#top)

==> dtfu_install-1.0.3.tar.gz: doc/readme.md <==
# 自动数据FTP上传 :id=top

> _Doc Ver:_ 1.3  
_App Ver:_ 1.0.3  
_Date:_ 12/21/2022

dtfu: Data ftp upload;  
定期检测目标数据目录；  
并将未上传的历史数据或则最新数据上传到指定ftp服务器中。

## 1. 安装 :id=install

  * 下载安装包:  
    http://112.74.80.60/tools/dtfu/linux/amd64/latest/dtfu_install.tar.gz
  * 拷贝: 将下载的安装包拷贝至系统的用户根目录;
  * 解压
    通过系统命令行进入下载包存放目录，运行指令解压;
    ```
        tar -xzvf dtfu_install.tar.gz
    ```
  * 安装
    ```
        cd dtfu_install
        bash install.sh
    ```
  * 配置启动参数
    需要配置启动参数才能运行，系统无默认配置文件。
    可以配置为多个FTP服务器接收模式。
    ```
        cd ~/dtfu
        ./configure
    ```
  * 增加自启动
    在自启动脚本中，增加以下命令实现自启动，重启系统后生效。   
    如果系统中安装有解调仪单机程序，需要将本程序自启动项目置于解调仪程序前。
    ```
        sudo -u debian dtfu_run start &
        
        debian: 为系统默认的sudo主账户
    ```

## 2. 配置参数 :id=configure 

   ```
        Log backup days [default: 15]
        日志文件记录过多检查的检查时间，单位：天
        日志中有的记录，如果实际中的文件已经被删除了；
        则将日志记录转存到历史日志中（log/）目录下按月份创建文件。

        Source data dir [default: /var/sa/data/rt/]
        数据源目录。
        
        Log file [default: dtfu.log] 
        上传文件记录 

        Source data files ignored [default: *.dat]
        是否忽略特定文件。

        Source files deleted after uploaded, 'yes' or 'no' [default: no]
        是否删除数据源文件，如果有多个FTP服务器上传，此项失效。

        Check interval [default: 6]
        新文件检查时间间隔（单位：秒）。

        FTP server number [default: 2]
        需要配置的FTP接收服务器的数量。

        Detect ftp config file: /var/sa/conf/data_save.json, 'y' for load it.
        如果系统安装了"sa"程序，将自动侦测配置文件，并自动禁用保存配置中的sa自动FTP上传功能。

        User & Passwd: FTP的用户名密码。
        URL: FTP的接收网络地址。

        Test FTP link now? 'y' for yes. 
        确认是否FTP配置正确，将自动上传测试文件以确认。
   ```

## 3. 进度查看 :id=monitor 

  通过广播接口，可以实时查看转存程序的运行状态，包括异常，结束，正在处理的文件情况。
  * Linux系统
  在与备份服务器同网络的任意Linux电脑上，运行以下程序;
  ```
    nc -l -u -k -p 7070

    7070: 为dtfu.cfg（交互配置后自动生成）文件中"process_udp_port"定义的接口。
    -l: 监听  
    -u: upd  
    -k: 保持链接，不会因为一帧数据接收后就结束。  
    -p: 监听端口  
  ```

## 更改历史 :id=changelog

|版本|日期|说明|
|:--:|----|----------|
|1.3|12/21/2022|1. 增加Log日志备份，解决单Log文件运行时间长而记录内容过多问题。|
|1.2|12/19/2022|1. 修改启动方式，增加多服务端上传;<br/>2. 增加选择文件过滤功能;<br/>3. 更改配置文件修改方式为交互式。|
|1.1|12/10/2022|1. 修正正写入文件的探测，并禁止上传。|
|1.0|12/10/2022|1. 适用新文件格式创建帮助。|

------

[Top](#top)
